@@ -19,10 +19,6 @@
 
 #include <ModemManagerQt/Manager>
 
-#include <QDBusReply>
-
-#include <QCoroDBus>
-
 ConnectionIcon::ConnectionIcon(QObject *parent)
     : QObject(parent)
     , m_wirelessNetwork(nullptr)
