@@ -7,6 +7,8 @@
 #ifndef PLASMA_NM_WIRED_SECURITY_H
 #define PLASMA_NM_WIRED_SECURITY_H
 
+#include "plasmanm_editor_export.h"
+
 #include <QWidget>
 
 #include <NetworkManagerQt/Security8021xSetting>
@@ -19,7 +21,7 @@ namespace Ui
 class WiredSecurity;
 }
 
-class Q_DECL_EXPORT WiredSecurity : public SettingWidget
+class PLASMANM_EDITOR_EXPORT WiredSecurity : public SettingWidget
 {
     Q_OBJECT
 public:
