@@ -624,40 +624,6 @@ QString UiUtils::labelFromWirelessSecurity(NetworkManager::WirelessSecurityType
     return tip;
 }
 
-QString UiUtils::formatDateRelative(const QDateTime &lastUsed)
-{
-    QString lastUsedText;
-    if (lastUsed.isValid()) {
-        const QDateTime now = QDateTime::currentDateTime();
-        if (lastUsed.daysTo(now) == 0) {
-            const int secondsAgo = lastUsed.secsTo(now);
-            if (secondsAgo < (60 * 60)) {
-                const int minutesAgo = secondsAgo / 60;
-                lastUsedText = i18ncp("Label for last used time for a network connection used in the last hour, as the number of minutes since usage",
-                                      "One minute ago",
-                                      "%1 minutes ago",
-                                      minutesAgo);
-            } else {
-                const int hoursAgo = secondsAgo / (60 * 60);
-                lastUsedText = i18ncp("Label for last used time for a network connection used in the last day, as the number of hours since usage",
-                                      "One hour ago",
-                                      "%1 hours ago",
-                                      hoursAgo);
-            }
-        } else if (lastUsed.daysTo(now) == 1) {
-            lastUsedText = i18nc("Label for last used time for a network connection used the previous day", "Yesterday");
-        } else {
-            lastUsedText = QLocale().toString(lastUsed.date(), QLocale::ShortFormat);
-        }
-    } else {
-        lastUsedText = i18nc(
-            "Label for last used time for a "
-            "network connection that has never been used",
-            "Never");
-    }
-    return lastUsedText;
-}
-
 QString UiUtils::formatLastUsedDateRelative(const QDateTime &lastUsed)
 {
     QString lastUsedText;
