@@ -7,10 +7,14 @@
 #ifndef PLASMA_NM_CREATABLE_CONNECTIONS_MODEL_H
 #define PLASMA_NM_CREATABLE_CONNECTIONS_MODEL_H
 
+#include "plasmanm_internal_export.h"
+
 #include <NetworkManagerQt/ConnectionSettings>
 #include <QAbstractListModel>
 
-class Q_DECL_EXPORT CreatableConnectionItem : public QObject
+#include <qqmlregistration.h>
+
+class PLASMANM_INTERNAL_EXPORT CreatableConnectionItem : public QObject
 {
     Q_OBJECT
 public:
@@ -61,9 +65,10 @@ private:
     QString m_vpnType;
 };
 
-class Q_DECL_EXPORT CreatableConnectionsModel : public QAbstractListModel
+class PLASMANM_INTERNAL_EXPORT CreatableConnectionsModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
 public:
     explicit CreatableConnectionsModel(QObject *parent = nullptr);
     ~CreatableConnectionsModel() override;
